==> appier-1.17.6.tar.gz: appier-1.17.6/setup.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

# Hive Appier Framework
# Copyright (c) 2008-2018 Hive Solutions Lda.
#
# This file is part of Hive Appier Framework.
#
# Hive Appier Framework is free software: you can redistribute it and/or modify
# it under the terms of the Apache License as published by the Apache
# Foundation, either version 2.0 of the License, or (at your option) any
# later version.
#
# Hive Appier Framework is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# Apache License for more details.
#
# You should have received a copy of the Apache License along with
# Hive Appier Framework. If not, see <http://www.apache.org/licenses/>.

__author__ = "João Magalhães <joamag@hive.pt>"
""" The author(s) of the module """

__version__ = "1.0.0"
""" The version of the module """

__revision__ = "$LastChangedRevision$"
""" The revision number of the module """

__date__ = "$LastChangedDate$"
""" The last change date of the module """

__copyright__ = "Copyright (c) 2008-2018 Hive Solutions Lda."
""" The copyright for the module """

__license__ = "Apache License, Version 2.0"
""" The license for the module """

import os
import setuptools

def read_file(path):
    if not os.path.exists(path): return None
    file = open(path, "r")
    try: return file.read()
    finally: file.close()

setuptools.setup(
    name = "appier",
    version = "1.17.6",
    author = "Hive Solutions Lda.",
    author_email = "development@hive.pt",
    description = "Appier Framework",
    license = "Apache License, Version 2.0",
    keywords = "appier framework web json wsgi",
    url = "http://appier.hive.pt",
    zip_safe = False,
    packages = [
        "appier",
        "appier.test"
    ],
    test_suite = "appier.test",
    package_dir = {
        "" : os.path.normpath("src")
    },
    package_data = {
        "appier" : [
            "res/static/css/*",
            "res/static/images/*",
            "res/static/js/*",
            "res/templates/*"
        ]
    },
    classifiers = [
        "Development Status :: 5 - Production/Stable",
        "Topic :: Utilities",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.6",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3.0",
        "Programming Language :: Python :: 3.1",
        "Programming Language :: Python :: 3.2",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6"
    ],
    long_description = read_file("README.rst")
)

==> appier-1.17.32.tar.gz: appier-1.17.32/setup.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

# Hive Appier Framework
# Copyright (c) 2008-2018 Hive Solutions Lda.
#
# This file is part of Hive Appier Framework.
#
# Hive Appier Framework is free software: you can redistribute it and/or modify
# it under the terms of the Apache License as published by the Apache
# Foundation, either version 2.0 of the License, or (at your option) any
# later version.
#
# Hive Appier Framework is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# Apache License for more details.
#
# You should have received a copy of the Apache License along with
# Hive Appier Framework. If not, see <http://www.apache.org/licenses/>.

__author__ = "João Magalhães <joamag@hive.pt>"
""" The author(s) of the module """

__version__ = "1.0.0"
""" The version of the module """

__revision__ = "$LastChangedRevision$"
""" The revision number of the module """

__date__ = "$LastChangedDate$"
""" The last change date of the module """

__copyright__ = "Copyright (c) 2008-2018 Hive Solutions Lda."
""" The copyright for the module """

__license__ = "Apache License, Version 2.0"
""" The license for the module """

import os
import setuptools

def read_file(path):
    if not os.path.exists(path): return None
    file = open(path, "r")
    try: return file.read()
    finally: file.close()

setuptools.setup(
    name = "appier",
    version = "1.17.32",
    author = "Hive Solutions Lda.",
    author_email = "development@hive.pt",
    description = "Appier Framework",
    license = "Apache License, Version 2.0",
    keywords = "appier framework web json wsgi",
    url = "http://appier.hive.pt",
    zip_safe = False,
    packages = [
        "appier",
        "appier.test"
    ],
    test_suite = "appier.test",
    package_dir = {
        "" : os.path.normpath("src")
    },
    package_data = {
        "appier" : [
            "res/static/css/*",
            "res/static/images/*",
            "res/static/js/*",
            "res/templates/*"
        ]
    },
    classifiers = [
        "Development Status :: 5 - Production/Stable",
        "Topic :: Utilities",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.6",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3.0",
        "Programming Language :: Python :: 3.1",
        "Programming Language :: Python :: 3.2",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7"
    ],
    long_description = read_file("README.rst")
)
